package net.knarcraft.playerpayouts.command;

import net.knarcraft.knarlib.formatting.StringFormatter;
import net.knarcraft.playerpayouts.PlayerPayouts;
import net.knarcraft.playerpayouts.config.Configuration;
import net.knarcraft.playerpayouts.config.Translatable;
import net.knarcraft.playerpayouts.manager.PermissionManager;
import net.knarcraft.playerpayouts.util.StringHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * A command for overriding payments for specific groups
 */
public class SetGroupPaymentCommand implements CommandExecutor {

    private final Configuration configuration;

    /**
     * Instantiates a new set group payment command
     *
     * @param configuration <p>The configuration to use</p>
     */
    public SetGroupPaymentCommand(@NotNull Configuration configuration) {
        this.configuration = configuration;
    }

    @Override
    public boolean onCommand(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s,
                             @NotNull String[] arguments) {
        StringFormatter stringFormatter = PlayerPayouts.getStringFormatter();

        if (!PermissionManager.isInitialized()) {
            stringFormatter.displayErrorMessage(commandSender, Translatable.GROUP_PAYOUTS_UNAVAILABLE);
            return false;
        }

        // Display all current group payment overrides
        if (arguments.length == 0) {
            StringBuilder builder = new StringBuilder(stringFormatter.getUnformattedColoredMessage(
                    Translatable.CURRENT_PAYOUT_OVERRIDE));
            for (Map.Entry<String, Double> entry : configuration.getGroupPayouts().entrySet()) {
                if (entry.getValue() == null) {
                    continue;
                }
                builder.append(stringFormatter.replacePlaceholders(Translatable.PAYOUT_OVERRIDE_LIST_FORMAT,
                        List.of("{subject}", "{value}"), List.of(entry.getKey(), String.valueOf(entry.getValue()))));
            }
            stringFormatter.displaySuccessMessage(commandSender, builder.toString());
            return true;
        }

        if (Arrays.stream(PermissionManager.getPermissionGroups()).noneMatch(item -> item.equals(arguments[0]))) {
            stringFormatter.displayErrorMessage(commandSender, Translatable.GROUP_INVALID);
            return false;
        }

        // Display the specified group's payment override
        if (arguments.length == 1) {
            String output = stringFormatter.getUnformattedMessage(Translatable.CURRENT_PAYOUT_OVERRIDE);
            Double value = configuration.getGroupPayout(arguments[0]);
            if (value != null) {
                output += stringFormatter.replacePlaceholders(Translatable.PAYOUT_OVERRIDE_LIST_FORMAT,
                        List.of("{subject}", "{value}"), List.of(arguments[0], String.valueOf(value)));
            }
            stringFormatter.displaySuccessMessage(commandSender, output);
            return true;
        }

        try {
            String group = arguments[0];
            if (StringHelper.isNonValue(arguments[1])) {
                configuration.setGroupPayout(group, null);
                stringFormatter.displaySuccessMessage(commandSender, stringFormatter.replacePlaceholder(
                        Translatable.GROUP_PAYOUT_CLEARED, "{group}", group));
            } else {
                Double payout = Double.parseDouble(arguments[1]);
                configuration.setGroupPayout(group, payout);
                stringFormatter.displaySuccessMessage(commandSender, stringFormatter.replacePlaceholders(
                        Translatable.GROUP_PAYOUT_SET, List.of("{group}", "{value}"),
                        List.of(group, String.valueOf(payout))));
            }
            return true;
        } catch (NumberFormatException exception) {
            stringFormatter.displayErrorMessage(commandSender, Translatable.PAYOUT_NUMBER_REQUIRED);
            return false;
        }
    }

}
