package net.knarcraft.playerpayouts.command;

import net.knarcraft.playerpayouts.util.TabCompletionHelper;
import org.bukkit.Bukkit;
import org.bukkit.OfflinePlayer;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabCompleter;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * The tab-completer for the set player payment command
 */
public class SetPlayerPaymentTabCompleter implements TabCompleter {

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s,
                                      @NotNull String[] arguments) {
        if (arguments.length == 1) {
            // List online players
            return TabCompletionHelper.filterMatchingContains(getPlayerNames(), arguments[0]);
        } else if (arguments.length == 2) {
            // List possible payout values
            return TabCompletionHelper.filterMatchingStartsWith(List.of("clear", "null", "none", "5", "10", "100"),
                    arguments[1]);
        }
        return new ArrayList<>();
    }

    /**
     * Gets names of all online players, and ids of offline players
     *
     * @return <p>The names and ids of all known players</p>
     */
    private @NotNull List<String> getPlayerNames() {
        List<String> playerNames = new ArrayList<>();
        for (Player player : Bukkit.getOnlinePlayers()) {
            playerNames.add(player.getName());
        }
        for (OfflinePlayer offlinePlayer : Bukkit.getOfflinePlayers()) {
            if (offlinePlayer.getName() != null) {
                playerNames.add(offlinePlayer.getName());
            } else {
                playerNames.add(offlinePlayer.getUniqueId().toString());
            }
        }
        return playerNames;
    }

}
