package net.knarcraft.playerpayouts.config;

import org.jetbrains.annotations.NotNull;

public enum ConfigurationKey {

    /**
     * The default base pay for every player
     */
    DEFAULT_PAYOUT("defaultPayout"),

    /**
     * The amount of hours a player needs to pay until they get a payment bonus
     */
    HOURS_UNTIL_BONUS("hoursUntilBonus"),

    /**
     * The bonus multiplier applied for hours played ((hours played / hours until bonus) * bonusMultiplier) + payout
     */
    BONUS_MULTIPLIER("bonusMultiplier"),

    /**
     * The amount of minutes between each payout
     */
    PAYOUT_DELAY("payoutDelay"),

    /**
     * The percentage of the payment to pay AFK players
     */
    AFK_PERCENTAGE("afkPercentage"),

    /**
     * Whether to inform the user each time they receive payment
     */
    DISPLAY_PAYMENT_MESSAGE("displayPaymentMessage"),

    /**
     * The rules for how the base payouts are calculated
     */
    PAYOUT_RULES("payoutRules"),

    /**
     * Payout overrides for each group
     */
    GROUP_PAYOUTS("groupPayouts"),

    /**
     * Payout override for each player
     */
    PLAYER_PAYOUTS("playerPayouts"),
    ;

    private final String path;

    /**
     * Instantiates a new configuration key
     *
     * @param path <p>The path of this configuration in the configuration file</p>
     */
    ConfigurationKey(@NotNull String path) {
        this.path = path;
    }

    /**
     * Gets the path in the configuration file of this configuration key
     *
     * @return <p>This key's path</p>
     */
    public @NotNull String getPath() {
        return this.path;
    }

}
