package net.knarcraft.playerpayouts.config;

import net.knarcraft.knarlib.formatting.TranslatableMessage;
import org.jetbrains.annotations.NotNull;

/**
 * Player Payout's translatable strings
 */
public enum Translatable implements TranslatableMessage {

    /**
     * The message displayed when group payouts are unavailable because of a missing permission plugin
     */
    GROUP_PAYOUTS_UNAVAILABLE,

    /**
     * The message displayed when the plugin is reloaded
     */
    PLUGIN_RELOADED,

    /**
     * The message displayed when a group payout override has been cleared
     */
    GROUP_PAYOUT_CLEARED,

    /**
     * The message displayed when a group payout override has been set
     */
    GROUP_PAYOUT_SET,

    /**
     * The message displayed when a non-number has been given as the payout
     */
    PAYOUT_NUMBER_REQUIRED,

    /**
     * The message displayed when an invalid player name or UUID has been given
     */
    PLAYER_ID_REQUIRED,

    /**
     * The message displayed when a player payout override has been cleared
     */
    PLAYER_PAYOUT_CLEARED,

    /**
     * The message displayed when a player payout override has been set
     */
    PLAYER_PAYOUT_SET,

    /**
     * The message displayed when a payout has been received
     */
    PAYOUT_RECEIVED,

    /**
     * The message displayed when an invalid permission group has been provided
     */
    GROUP_INVALID,

    /**
     * The text displayed when listing current payout overrides
     */
    CURRENT_PAYOUT_OVERRIDE,

    /**
     * The format to use when listing current payout overrides
     */
    PAYOUT_OVERRIDE_LIST_FORMAT,

    ;

    @Override
    public @NotNull TranslatableMessage[] getAllMessages() {
        return Translatable.values();
    }

}
