package net.knarcraft.playerpayouts.manager;

import net.milkbowl.vault.permission.Permission;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

/**
 * A manager that performs all Permission tasks
 */
public final class PermissionManager {

    private static Permission permission;

    private PermissionManager() {

    }

    /**
     * Initializes the permission manager
     *
     * @param permission <p>The permission object to use for everything permission-related</p>
     */
    public static void initialize(@NotNull Permission permission) {
        PermissionManager.permission = permission;
    }

    /**
     * Checks whether the permission manager has been initialized
     *
     * @return <p>True if the permission manager has been initialized</p>
     */
    public static boolean isInitialized() {
        return PermissionManager.permission != null;
    }

    /**
     * Gets all groups of a player
     *
     * @param player <p>The player to get the groups for</p>
     * @return <p>The player's groups</p>
     */
    public static @NotNull String[] getPlayerGroups(@NotNull Player player) {
        return permission.getPlayerGroups(player);
    }

    /**
     * Gets all available permission groups
     *
     * @return <p>All available permission groups</p>
     */
    public static @NotNull String[] getPermissionGroups() {
        return permission.getGroups();
    }

}
